import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/** DemoHTMLButton - demonstrate the use of html-tagged text in buttons.<p>
*
* Both <code>JButton</code> and <code>JLabel</code> allow their
* text to include html tags. To do so, simply
* put <code>&lt;html&gt;</code> at the beginning of the text string,
* then use any valid html tags within the text string to
* control the appearance and layout of the text.  This is used,
* for example, to vary the text font, style, size, or color, or
* even to include line breaks for multi-line text in buttons
* or labels.<p>
*
* If, for example, you are
* building a custom web browser and you want a dedicated button
* for the Google search engine,
* you could create the button using the familiar Google
* colours as shown here.  Examine the source code
* for further details.<p>
*
* Screen snap ...<p>
* <center><img src="DemoHTMLButton-1.gif"></center><p>
*
* @see <a href="DemoHTMLButton.java">source code</a>
* @author Scott MacKenzie, 2009-2011
*/
public class DemoHTMLButton
{
   public static void main(String[] args)
   {
      DemoHTMLButtonFrame frame = new DemoHTMLButtonFrame();
      frame.setTitle("DemoHTMLButton");
      frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      frame.pack();
      frame.setVisible(true);
   }
}

// -----------------------------
// define the application window
// -----------------------------

class DemoHTMLButtonFrame extends JFrame implements ActionListener 
{
	// the following avoids a "warning" with Java 1.5.0 complier (?)
	static final long serialVersionUID = 42L;

   // -----------------------------------------------------------------
   // declare variables and components accessed by more than one method
   // -----------------------------------------------------------------

   private JButton b;

   // -----------
   // constructor
   // -----------

   public DemoHTMLButtonFrame()
   {
      // -------------------------------
      // create and configure components
      // -------------------------------

      b = new JButton("<html><b>" +
         "<u><font color = #194dd4>G</font></u>" +
         "<font color = #d41900>o</font>" +
         "<font color = #d0Da00>o</font>" +
         "<font color = #194DD4>g</font>" +
         "<font color = #31d039>l</font>" +
         "<font color = #d41900>e</font>" +
         "</b>");

      b.setBackground(Color.white);
      b.setMnemonic(KeyEvent.VK_G);

      // -------------
      // add listeners
      // -------------

      b.addActionListener(this);

      // ------------------
      // arrange components
      // ------------------

      // put components in a panel

      JPanel panel = new JPanel();
      panel.add(b);

      // make the panel this extended JFrame's content pane

      this.setContentPane(panel);
   }

   // -------------------------------
   // implement ActionListener method
   // -------------------------------

   public void actionPerformed(ActionEvent ae)
   {
      System.out.println("Go to http://www.google.com/");
   }
}
